tools

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: BSD-3-Clause Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PNGImageData

type PNGImageData []byte

type RichContent

type RichContent struct {
	TextContent  []string
	ImageContent []PNGImageData
}

RichContent is used as a tool output, when unstructured content should be used. That is, the tool will have no output schema and `structuredContent` will be `nil`. This should only be used when the tool needs to return content like images, sound, or resources.

type Tool

type Tool interface {
	Name() string
	AddToServer(server *mcp.Server) error
}

type ToolWithStructuredContentOutput

type ToolWithStructuredContentOutput[ToolInput any, ToolOutput any] interface {
	Tool
	Handler() mcp.ToolHandlerFor[ToolInput, ToolOutput]
}

type ToolWithUnstructuredContentOutput

type ToolWithUnstructuredContentOutput[ToolInput any] interface {
	Tool
	Handler() mcp.ToolHandlerFor[ToolInput, any]
}

Directories

Path Synopsis
Package basetool contains a wrapper for the MCP SDK Tools.
Package basetool contains a wrapper for the MCP SDK Tools.
multisession
singlesession
utils

Jump to